==> kubernetes-model-node-5.8.1-sources.jar: io/fabric8/kubernetes/api/model/node/v1/SchedulingFluent.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SchedulingFluent<A extends io.fabric8.kubernetes.api.model.node.v1.SchedulingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToNodeSelector(java.lang.String key,java.lang.String value);
  public A addToNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromNodeSelector(java.lang.String key);
  public A removeFromNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getNodeSelector();
  public <K,V>A withNodeSelector(java.util.Map<java.lang.String,java.lang.String> nodeSelector);
  public java.lang.Boolean hasNodeSelector();
  public A addToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A setToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Toleration> getTolerations();
  public io.fabric8.kubernetes.api.model.Toleration getToleration(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Toleration getFirstToleration();
  public io.fabric8.kubernetes.api.model.Toleration getLastToleration();
  public io.fabric8.kubernetes.api.model.Toleration getMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public java.lang.Boolean hasMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public A withTolerations(java.util.List<io.fabric8.kubernetes.api.model.Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public java.lang.Boolean hasTolerations();
  public A addNewToleration(java.lang.String effect,java.lang.String key,java.lang.String operator,java.lang.Long tolerationSeconds,java.lang.String value);
  
}

==> kubernetes-model-node-5.10.1-sources.jar: io/fabric8/kubernetes/api/model/node/v1/SchedulingFluent.java <==
package io.fabric8.kubernetes.api.model.node.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface SchedulingFluent<A extends io.fabric8.kubernetes.api.model.node.v1.SchedulingFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToNodeSelector(java.lang.String key,java.lang.String value);
  public A addToNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public A removeFromNodeSelector(java.lang.String key);
  public A removeFromNodeSelector(java.util.Map<java.lang.String,java.lang.String> map);
  public java.util.Map<java.lang.String,java.lang.String> getNodeSelector();
  public <K,V>A withNodeSelector(java.util.Map<java.lang.String,java.lang.String> nodeSelector);
  public java.lang.Boolean hasNodeSelector();
  public A addToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A setToTolerations(java.lang.Integer index,io.fabric8.kubernetes.api.model.Toleration item);
  public A addToTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A addAllToTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public A removeFromTolerations(io.fabric8.kubernetes.api.model.Toleration... items);
  public A removeAllFromTolerations(java.util.Collection<io.fabric8.kubernetes.api.model.Toleration> items);
  public java.util.List<io.fabric8.kubernetes.api.model.Toleration> getTolerations();
  public io.fabric8.kubernetes.api.model.Toleration getToleration(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.Toleration getFirstToleration();
  public io.fabric8.kubernetes.api.model.Toleration getLastToleration();
  public io.fabric8.kubernetes.api.model.Toleration getMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public java.lang.Boolean hasMatchingToleration(java.util.function.Predicate<io.fabric8.kubernetes.api.model.Toleration> predicate);
  public A withTolerations(java.util.List<io.fabric8.kubernetes.api.model.Toleration> tolerations);
  public A withTolerations(io.fabric8.kubernetes.api.model.Toleration... tolerations);
  public java.lang.Boolean hasTolerations();
  public A addNewToleration(java.lang.String effect,java.lang.String key,java.lang.String operator,java.lang.Long tolerationSeconds,java.lang.String value);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  
}
